@@ -2,7 +2,7 @@ call.eqs <- function(EQSpgm, EQSmodel, serial, Rmatrix = NA, datname = NA, LEN =
 {
   #EQSpgm ... EQS directory
   #EQSmodel ... path, where eqs-file is located
-  #serial ... EQS serial number 
+  #serial ... EQS serial number as character
   #LEN ... Number of working array unit.  By default, it is 2,000,000 8 bytes units
   
   #--------- change working directory where eqs file is located ---------
@@ -10,7 +10,7 @@ call.eqs <- function(EQSpgm, EQSmodel, serial, Rmatrix = NA, datname = NA, LEN =
   n <- length(filedir.split) 
   filedir <- paste(filedir.split[1:(n-1)], collapse = "/")
   if (n > 1) setwd(filedir)
-  
+   
   #--------- string specifications -----------
   outname <- strsplit(filedir.split[n], "\\.")[[1]][1]
   file.out <- paste(outname, ".out",sep = "" )
@@ -33,7 +33,10 @@ call.eqs <- function(EQSpgm, EQSmodel, serial, Rmatrix = NA, datname = NA, LEN =
 # IN=   input EQS command file (please note that input data is specified in the EQS command file)
 # OUT=  EQS output file name
 
-  EQScmd <- paste(EQSpgm, filepathin, fileout, lenstring, serial)
+  EQScmd <- paste(deparse(EQSpgm), filepathin, fileout, lenstring, serstring)
+  
+  RetCode <- system(EQScmd, intern = FALSE, ignore.stderr = TRUE, wait = TRUE, input = NULL,
+      show.output.on.console = FALSE, minimized = FALSE, invisible = FALSE)
   
   RetCode <- system(EQScmd, intern = FALSE, ignore.stderr = TRUE, wait = TRUE, input = NULL,
       show.output.on.console = FALSE, minimized = FALSE, invisible = FALSE)
